======
capitalize-name
======


.. image:: https://img.shields.io/badge/pypi-v1.0.0-orange.svg
    :target: https://pypi.python.org/pypi/capitalize-name

.. image:: https://img.shields.io/badge/python-2.6%2C%202.7%2C%203.3+-blue.svg
    :target: https://travis-ci.org/sxslex/capitalize-name.svg?branch=master

.. image:: https://travis-ci.org/sxslex/capitalize-name.svg?branch=master
    :target: https://travis-ci.org/sxslex/capitalize-name

.. image:: https://img.shields.io/badge/license--blue.svg
    :target: https://github.com/sxslex/capitalize-name/blob/master/LICENSE


Returns the correct writing of a compound name, respecting the first letters of the names in upper case.
Passes all original unittests.


Usage
=====

.. code:: pycon

    >>> import capitalize_name
    >>> capitalize_name.capitalize('AV. DOM PEDRO DE ALMEIDA I')
    'Av. Dom Pedro de Almeida I'


Installation
============

Use ``pip`` or ``easy_install``:

.. code::

    $ pip install capitalize-name


Development
===========

Use py.test to run unittests

